- Translate cooperative status selection field, the terms to translate are:

  - shift_status_up_to_date,
  - shift_status_holidays,
  - shift_status_warning,
  - shift_status_extension,
  - shift_status_suspended,
  - shift_status_exempted,
  - shift_status_unsubscribed,
  - shift_status_resigning.

- Configure "Send weekly shift summary" cron:

  - Its interval number (default = 7) should be consistent with notice (default = 1) and period (default = 7).
